@@ -87,7 +87,10 @@ def parse(
             pattern = pattern[1:]
             if pattern:
                 if check_pass(pattern):
-                    ignore_all = True
+                    if pattern.endswith("/"):
+                        ignores.append("*/")
+                    else:
+                        ignore_all = True
                 else:
                     ignores.append(pattern)
         elif check_mimetype and pattern.removeprefix("!").startswith(
@@ -105,14 +108,20 @@ def parse(
             pattern = pattern[1:]
             if pattern:
                 if check_pass(pattern):
-                    show_all = True
+                    if pattern.endswith("/"):
+                        shows.append("*/")
+                    else:
+                        show_all = True
                 else:
                     shows.append(pattern)
         else:
             if ignore_all:
                 continue
             if check_pass(pattern):
-                ignore_all = True
+                if pattern.endswith("/"):
+                    ignores.append("*/")
+                else:
+                    ignore_all = True
             else:
                 ignores.append(pattern)
     if show_all:
